pub struct CustomVal(/* private fields */);Expand description
Contains a custom value.
Implementations
Sourceimpl CustomVal
impl CustomVal
Sourcepub fn new(val: impl CustomType) -> CustomVal
pub fn new(val: impl CustomType) -> CustomVal
Create a new CustomVal from any type that implements CustomType.
Sourcepub fn get<T>(&self) -> Result<CustomValRef<'_, T>, CustomValError>where
T: CustomType,
pub fn get<T>(&self) -> Result<CustomValRef<'_, T>, CustomValError>where
T: CustomType,
Get the underlying value of Self if it is of type T or else return None.
Panic
Panics if the value if the value is under a Self::get_mut.
Sourcepub fn get_mut<T>(&self) -> Result<CustomValMut<'_, T>, CustomValError>where
T: CustomType,
pub fn get_mut<T>(&self) -> Result<CustomValMut<'_, T>, CustomValError>where
T: CustomType,
Get the underlying value of Self if it is of type T or else return None.
Panic
Panics if the value if the value is under a Self::get or Self::get_mut.